#-*- coding: utf-8 -*-
#############################################################################
#                                                                           #
#   Copyright (c) 2008 Gregor Giesen <giesen@zaehlwerk.net>                 #
#                                                                           #
# This program is free software; you can redistribute it and/or modify      #
# it under the terms of the GNU General Public License as published by      #
# the Free Software Foundation; either version 3 of the License, or         #
# (at your option) any later version.                                       #
#                                                                           #
# This program is distributed in the hope that it will be useful,           #
# but WITHOUT ANY WARRANTY; without even the implied warranty of            #
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             #
# GNU General Public License for more details.                              #
#                                                                           #
# You should have received a copy of the GNU General Public License         #
# along with this program.  If not, see <http://www.gnu.org/licenses/>.     #
#                                                                           #
#############################################################################
"""
$Id$
"""
__docformat__ = 'reStructuredText'

from zw.widget.i18n import MessageFactory as _

from zope.component import adapter, adapts
from zope.interface import implementsOnly, implementer
from zope.app.security.interfaces import IUnauthenticatedPrincipal

from z3c.form.browser import widget
from z3c.form.interfaces import IFieldWidget, IFormLayer
from z3c.form.widget import Widget, FieldWidget

from z3c.schema.email.interfaces import IRFC822MailAddress
from zw.widget.email.interfaces import IEmailWidget

class EmailWidget(widget.HTMLTextInputWidget, Widget):
    """Email widget.
    """
    implementsOnly(IEmailWidget)
    
    klass = u'email-widget'
    value = u''

    obscured = False

    def update(self):
        # Obscure email if unauthenticated.
        self.obscured = IUnauthenticatedPrincipal.providedBy(
            self.request.principal)
        super(EmailWidget, self).update()
        widget.addFieldClass(self)

@adapter(IRFC822MailAddress, IFormLayer)
@implementer(IFieldWidget)
def EmailFieldWidget(field, request):
    """IFieldWidget factory for EmailWidget.
    """
    return FieldWidget(field, EmailWidget(request))




#-*- coding: utf-8 -*-
#############################################################################
#                                                                           #
#   Copyright (c) 2007-2008 Gregor Giesen <giesen@zaehlwerk.net>            #
#                                                                           #
# This program is free software; you can redistribute it and/or modify      #
# it under the terms of the GNU General Public License as published by      #
# the Free Software Foundation; either version 3 of the License, or         #
# (at your option) any later version.                                       #
#                                                                           #
# This program is distributed in the hope that it will be useful,           #
# but WITHOUT ANY WARRANTY; without even the implied warranty of            #
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             #
# GNU General Public License for more details.                              #
#                                                                           #
# You should have received a copy of the GNU General Public License         #
# along with this program.  If not, see <http://www.gnu.org/licenses/>.     #
#                                                                           #
#############################################################################
"""
$Id$
"""
__docformat__ = 'reStructuredText'

from zw.widget.i18n import MessageFactory as _

import zope.schema.interfaces
from zope.component import adapter
from zope.interface import implementsOnly, implementer

from z3c.form.browser.textarea import TextAreaWidget
from z3c.form.interfaces import IFormLayer, IFieldWidget
from z3c.form.widget import FieldWidget

from zw.schema.richtext.interfaces import IRichText
from zw.widget.tiny.interfaces import ITinyWidget

try:
    from zc import resourcelibrary
    haveResourceLibrary = True
except ImportError:
    haveResourceLibrary = False

OPT_PREFIX = "mce_"
OPT_PREFIX_LEN = len(OPT_PREFIX)
MCE_LANGS=[]
import glob
import os

# initialize the language files
for langFile in glob.glob(
    os.path.join(os.path.dirname(__file__), 'tiny_mace', 'langs') + '/??.js'):
    MCE_LANGS.append(os.path.basename(langFile)[:2])

class TinyWidget(TextAreaWidget):
    """TinyMCE widget implementation.
    """
    implementsOnly(ITinyWidget)

    klass = u'tiny-widget'
    value = u''

    tiny_js = u""

    rows = 10
    cols = 60

    mce_theme = "advanced"
    mce_theme_advanced_buttons1 = "bold,italic,underline,separator,strikethrough,justifyleft,justifycenter,justifyright, justifyfull,bullist,numlist,undo,redo,link,unlink"
    mce_theme_advanced_buttons2 = ""
    mce_theme_advanced_buttons3 = ""
    mce_theme_advanced_toolbar_location = "top"
    mce_theme_advanced_toolbar_align = "left"
    mce_theme_advanced_statusbar_location = "bottom"
    mce_extended_valid_elements = "a[name|href|target|title|onclick],img[class|src|border=0|alt|title|hspace|vspace|width|height|align|onmouseover|onmouseout|name],hr[class|width|size|noshade],font[face|size|color|style],span[class|align|style]"

    def update(self):
        super(TinyWidget, self).update()


        if haveResourceLibrary:
            resourcelibrary.need('tiny_mce')

        mceOptions = []
        for k in dir(self):
            if k.startswith(OPT_PREFIX):
                v = getattr(self, k, None)
                v = v==True and 'true' or v==False and 'false' or v
                if v in ['true','false']:
                    mceOptions.append('%s : %s' % (k[OPT_PREFIX_LEN:],v))
                elif v is not None:
                    mceOptions.append('%s : "%s"' % (k[OPT_PREFIX_LEN:],v))
        mceOptions = ', '.join(mceOptions)
        if mceOptions:
            mceOptions += ', '
        if self.request.locale.id.language in MCE_LANGS:
            mceOptions += ('language : "%s", ' % \
                               self.request.locale.id.language)
            
        self.tiny_js = u"""
tinyMCE.init({ 
mode : "exact", %(options)s
elements : "%(id)s"
}
);
""" % { "id": self.id,
        "options": mceOptions }



@adapter(IRichText, IFormLayer)
@implementer(IFieldWidget)
def TinyFieldWidget(field, request):
    """IFieldWidget factory for TinyWidget.
    """
    return FieldWidget(field, TinyWidget(request))



import os, sys, urllib, urllib2
from zipfile import ZipFile
from HTMLParser import HTMLParser
from setuptools import setup, find_packages

def read(*rnames):
    return open(os.path.join(os.path.dirname(__file__), *rnames)).read()

name = 'zw.widget'
version = '0.1.6'
extpaths = []

tinymce_version = '3.2.1.1'
tinymce_src_name = 'tinymce_%s.zip' % tinymce_version.replace('.', '_')
tinymce_base_url = 'http://downloads.sourceforge.net/tinymce'
tinymce_dest = os.path.join(os.path.dirname(__file__),
                    'src', 'zw', 'widget', 'tiny', 'tiny_mce')
tinymce_lang_src_name = 'tinymce_lang_pack.zip'
tinymce_lang_base_url = 'http://services.moxiecode.com/i18n/'
tinymce_lang_post_url = tinymce_lang_base_url+'download.aspx'
params = dict(format='zip', product='tinymce')

class TinyMCELangParser(HTMLParser):
    
    params = {}

    def handle_startendtag(self, tag, attrs):
        attrs = dict(attrs)
        if tag == 'input' and attrs.get('type',None) == 'checkbox' and \
                'name' in attrs and 'value' in attrs:
            self.params[attrs['name']] = attrs['value']

# Download the TinyMCE code
if not os.path.exists(tinymce_src_name):
    if not os.path.exists(tinymce_src_name):
        f = open(tinymce_src_name, 'w')
        f.write(urllib2.urlopen( tinymce_base_url+'/'+tinymce_src_name).read())
        f.close()
    zfile = ZipFile(tinymce_src_name, 'r')
    prefix = 'tinymce/jscripts/tiny_mce/'
    lprefix = len(prefix)-1
    for zname in sorted(zfile.namelist()):
        assert zname.startswith('tinymce/')
        if zname.startswith(prefix):
            dname = tinymce_dest + zname[lprefix:]
            if dname[-1:] == '/':
                os.makedirs(dname)
            else:
                f = open(dname, 'w')
                f.write(zfile.read(zname))
                f.close()
    zfile.close()

# Download new language packs
if not os.path.exists(tinymce_lang_src_name):
    parser = TinyMCELangParser()
    parser.feed(urllib2.urlopen( tinymce_lang_base_url ).read())
    params.update(parser.params)
    fi = urllib2.urlopen( tinymce_lang_post_url, urllib.urlencode(params) )
    fo = open(tinymce_lang_src_name, 'w')
    fo.write( fi.read() )
    fo.close()
    fi.close()
    zfile = ZipFile(tinymce_lang_src_name, 'r')
    for zname in sorted(zfile.namelist()):
        dname = os.path.join(tinymce_dest, zname)
        if dname[-1:] == '/':
            os.makedirs(dname)
        else:
            f = open(dname, 'w')
            f.write(zfile.read(zname))
            f.close()
    zfile.close()

# Add files for packaging
lbase = len(os.path.dirname(tinymce_dest))+1
for path, dirs, files in os.walk(tinymce_dest):
    prefix = path[lbase:]
    for file in files:
        extpaths.append(os.path.join(prefix, file))

setup(name=name,

      # Fill in project info below
      version=version,
      description="Additional widgets for z3c.form",
      long_description=(
        read('README.txt') + \
            '\n\n' +
        read('src', 'zw', 'widget', 'color', 'README.txt') + \
            '\n\n' +
        read('src', 'zw', 'widget', 'email', 'README.txt') + \
            '\n\n' +
        read('src', 'zw', 'widget', 'lines', 'README.txt') + \
            '\n\n' +
        read('src', 'zw', 'widget', 'tiny', 'README.txt') + \
            '\n\n' +
        read('CHANGES.txt')),
      keywords='zope3',
      author='Gregor Giesen',
      author_email='giesen@zaehlwerk.net',
      url='https://launchpad.net/'+name,
      license='GPLv3',
      # Get more from http://www.python.org/pypi?%3Aaction=list_classifiers
      classifiers=['Development Status :: 4 - Beta',
                   'Programming Language :: Python',
                   'Environment :: Web Environment',
                   'Topic :: Internet :: WWW/HTTP :: WSGI :: Application',
                   'Framework :: Zope3',
                   'Intended Audience :: Developers',
                   'License :: OSI Approved :: GNU General Public License (GPL)',
                   ],

      packages=find_packages('src'),
      package_dir = {'': 'src'},
      namespace_packages=['zw'],
      include_package_data=True,
      package_data = {'zw.widget': extpaths},
      zip_safe=False,
      extras_require = dict(
        test = [ 'zope.testing',
                 'zope.app.testing',
                 'zope.app.zcmlfiles',
                 'zope.testbrowser',
                 'z3c.testsetup',
                ], ),
      install_requires = ['setuptools',
                          'zope.i18nmessageid',
                          'zope.interface',
                          'zope.schema',
                          'z3c.form',
                          'z3c.schema',
                          'zw.schema',
                          'zc.resourcelibrary',
                          ],
      )



#-*- coding: utf-8 -*-
#############################################################################
#                                                                           #
#   Copyright (c) 2008 Gregor Giesen <giesen@zaehlwerk.net>                 #
#                                                                           #
# This program is free software; you can redistribute it and/or modify      #
# it under the terms of the GNU General Public License as published by      #
# the Free Software Foundation; either version 3 of the License, or         #
# (at your option) any later version.                                       #
#                                                                           #
# This program is distributed in the hope that it will be useful,           #
# but WITHOUT ANY WARRANTY; without even the implied warranty of            #
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             #
# GNU General Public License for more details.                              #
#                                                                           #
# You should have received a copy of the GNU General Public License         #
# along with this program.  If not, see <http://www.gnu.org/licenses/>.     #
#                                                                           #
#############################################################################
"""
$Id$
"""
__docformat__ = 'reStructuredText'

from zw.widget.i18n import MessageFactory as _
from zope import schema
from z3c.form.interfaces import IWidget

class IEmailWidget(IWidget):
    """An email widget.
    """

    obscured = schema.Bool(
        title = _( u'label-zw.widget.email.obscured',
                   u"Obscured" ),
        description = _( u'help-zw.widget.email.obscured',
                         u"If true the address will be obscured "
                         u"to protect from spam bots." ),
        default = True )
